[xorg-commit-diffs] xc/programs/Xserver/hw/xwin InitOutput.c, 1.1.4.1.6.1, 1.1.4.1.6.1.4.1 XWin.man, 1.1.4.1.6.1, 1.1.4.1.6.1.4.1 XWin.rc, 1.1.4.1.6.1, 1.1.4.1.6.1.4.1 ddraw.h, 1.1.10.1, 1.1.10.1.4.1 obj_base.h, 1.1.10.1, 1.1.10.1.4.1 winconfig.c, 1.1.4.1.6.1, 1.1.4.1.6.1.4.1 winconfig.h, 1.1.10.1, 1.1.10.1.4.1 winkeybd.h, 1.1.10.1, 1.1.10.1.4.1 winshaddd.c, 1.1.4.1.6.1, 1.1.4.1.6.1.4.1 wintrayicon.c, 1.1.10.1, 1.1.10.1.4.1 winvideo.c, 1.1.10.1, 1.1.10.1.4.1 winwindow.h, 1.1.4.1.6.1, 1.1.4.1.6.1.4.1

Keith Packard xorg-commit at pdx.freedesktop.org
Sun Mar 28 19:47:32 PST 2004


Committed by: keithp

Update of /cvs/xorg/xc/programs/Xserver/hw/xwin
In directory pdx:/tmp/cvs-serv29897/programs/Xserver/hw/xwin

Modified Files:
      Tag: XORG-RELEASE-1-TM
	InitOutput.c XWin.man XWin.rc ddraw.h obj_base.h winconfig.c 
	winconfig.h winkeybd.h winshaddd.c wintrayicon.c winvideo.c 
	winwindow.h 
Log Message:
42. TM fixes for hw/xwin -- Harold will merge to CYGWIN. (Keith Packard)


Index: XWin.man
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/XWin.man,v
retrieving revision 1.1.4.1.6.1
retrieving revision 1.1.4.1.6.1.4.1
diff -u -d -r1.1.4.1.6.1 -r1.1.4.1.6.1.4.1
--- a/XWin.man	4 Mar 2004 17:48:19 -0000	1.1.4.1.6.1
+++ b/XWin.man	28 Mar 2004 17:18:11 -0000	1.1.4.1.6.1.4.1
@@ -48,13 +48,13 @@
 .I screen_number.
 .TP 8
 .B \-nodecoration
-Draw the Cygwin/XFree86 window without a border or title bar.
+Draw the Cygwin/X window without a border or title bar.
 .TP 8
 .B \-rootless
-EXPERIMENTAL: Run Cygwin/XFree86 in pseduo-rootless mode.
+EXPERIMENTAL: Run Cygwin/X in pseduo-rootless mode.
 .TP 8
 .B \-lesspointer
-Hide the Windows mouse pointer when over an inactive XFree86 window
+Hide the Windows mouse pointer when over an inactive X window
 .TP 8
 .B \-scrollbars
 In windowed mode, allow screens bigger than the Windows desktop.
@@ -96,14 +96,14 @@
 - The display mode can not be changed once the X server has started.
 .PP
 .SH AUTHORS
-XFree86 was originally ported to Cygwin by Dakshinamurthy Karra,
+X was originally ported to Cygwin by Dakshinamurthy Karra,
 Dr. Peter Busch, John Fortin, and Suhaib Siddiqi.
 .I XWin
-is maintained by the Cygwin/XFree86 project, with hosting services
-provided by RedHat.
+is maintained by the Cygwin/X project, with hosting services
+provided by freedesktop.org.
 .PP
 The following members, in alphabetical order by last name, of the
-Cygwin/XFree86 Team contributed to the XFree86 4.1.0 release:
+Cygwin/X Team contributed to the X.Org Foundation 6.7 release:
 .PP
 Robert Collins - Cygwin developer, miscellaneous
 .br
@@ -112,7 +112,7 @@
 .br
 Alexander Gottwald - AltGr handling for non-U.S. keyboards
 .br
-Alan Hourihane - XFree86 developer, patch reviewer, general programming guru
+Alan Hourihane - X developer, patch reviewer, general programming guru
 .br
 Pierre A Humblet - Debugging of socket-related crashes, developer
 .br

Index: XWin.rc
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/XWin.rc,v
retrieving revision 1.1.4.1.6.1
retrieving revision 1.1.4.1.6.1.4.1
diff -u -d -r1.1.4.1.6.1 -r1.1.4.1.6.1.4.1
--- a/XWin.rc	4 Mar 2004 17:48:19 -0000	1.1.4.1.6.1
+++ b/XWin.rc	28 Mar 2004 17:18:11 -0000	1.1.4.1.6.1.4.1
@@ -41,12 +41,12 @@
 DEPTH_CHANGE_BOX DIALOG DISCARDABLE	32, 32, 180, 100
 STYLE WS_POPUP | WS_CAPTION | WS_SYSMENU | WS_VISIBLE | DS_CENTER
 FONT 8, "MS Sans Serif"
-CAPTION "Cygwin/XFree86"
+CAPTION "Cygwin/X"
 BEGIN
   DEFPUSHBUTTON		"Dismiss", IDOK, 66, 80, 50, 14
-  CTEXT			"Cygwin/XFree86", IDC_STATIC, 40, 12, 100, 8
+  CTEXT			"Cygwin/X", IDC_STATIC, 40, 12, 100, 8
   CTEXT			"Disruptive screen configuration change.", IDC_STATIC, 7, 40, 166, 8
-  CTEXT			"Restore previous resolution to use Cygwin/XFree86.", IDC_STATIC, 7, 52, 166, 8
+  CTEXT			"Restore previous resolution to use Cygwin/X.", IDC_STATIC, 7, 52, 166, 8
 END
 
 
@@ -55,7 +55,7 @@
 EXIT_DIALOG DIALOG DISCARDABLE	32, 32, 180, 70
 STYLE WS_POPUP | WS_CAPTION | WS_SYSMENU | WS_VISIBLE | WS_TABSTOP | DS_CENTER
 FONT 8, "MS Sans Serif"
-CAPTION "Cygwin/XFree86 - Exit?"
+CAPTION "Cygwin/X - Exit?"
 BEGIN
   PUSHBUTTON "E&xit", IDOK, 55, 48, 30, 14
   DEFPUSHBUTTON "&Cancel", IDCANCEL, 95, 48, 30, 14

Index: ddraw.h
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/ddraw.h,v
retrieving revision 1.1.10.1
retrieving revision 1.1.10.1.4.1
diff -u -d -r1.1.10.1 -r1.1.10.1.4.1
--- a/ddraw.h	4 Mar 2004 17:48:19 -0000	1.1.10.1
+++ b/ddraw.h	28 Mar 2004 17:18:11 -0000	1.1.10.1.4.1
@@ -1,4 +1,4 @@
-/* $XFree86$ */
+/* $Id: $ */
 
 #ifndef __WINE_DDRAW_H
 #define __WINE_DDRAW_H

Index: obj_base.h
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/obj_base.h,v
retrieving revision 1.1.10.1
retrieving revision 1.1.10.1.4.1
diff -u -d -r1.1.10.1 -r1.1.10.1.4.1
--- a/obj_base.h	4 Mar 2004 17:48:19 -0000	1.1.10.1
+++ b/obj_base.h	28 Mar 2004 17:18:11 -0000	1.1.10.1.4.1
@@ -1,4 +1,4 @@
-/* $XFree86$ */
+/* $Id: $ */
 /*
  * This file defines the macros and types necessary to define COM interfaces, 
  * and the three most basic COM interfaces: IUnknown, IMalloc and IClassFactory.

Index: winconfig.c
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/winconfig.c,v
retrieving revision 1.1.4.1.6.1
retrieving revision 1.1.4.1.6.1.4.1
diff -u -d -r1.1.4.1.6.1 -r1.1.4.1.6.1.4.1
--- a/winconfig.c	4 Mar 2004 17:48:19 -0000	1.1.4.1.6.1
+++ b/winconfig.c	28 Mar 2004 17:18:11 -0000	1.1.4.1.6.1.4.1
@@ -126,6 +126,11 @@
   /* Parse config file into data structure */
 
   filename = xf86openConfigFile (CONFIGPATH, xf86ConfigFile, PROJECTROOT);
+    
+  /* Hack for backward compatibility */
+  if (!filename && from == X_DEFAULT)
+    filename = xf86openConfigFile (CONFIGPATH, "XF86Config", PROJECTROOT);
+
   if (filename)
     {
       winMsg (from, "Using config file: \"%s\"\n", filename);
@@ -258,7 +263,7 @@
   g_winInfo.xkb.variant = NULL;
   g_winInfo.xkb.options = NULL;
 # else
-  g_winInfo.xkb.rules = "xfree86";
+  g_winInfo.xkb.rules = "xorg";
   g_winInfo.xkb.model = "pc101";
   g_winInfo.xkb.layout = "us";
   g_winInfo.xkb.variant = NULL;

Index: winconfig.h
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/winconfig.h,v
retrieving revision 1.1.10.1
retrieving revision 1.1.10.1.4.1
diff -u -d -r1.1.10.1 -r1.1.10.1.4.1
--- a/winconfig.h	4 Mar 2004 17:48:19 -0000	1.1.10.1
+++ b/winconfig.h	28 Mar 2004 17:18:11 -0000	1.1.10.1.4.1
@@ -27,7 +27,7 @@
  *
  * Authors: Alexander Gottwald	
  */
-/* $XFree86$ */
+/* $Id: $ */
 #ifndef __WIN_CONFIG_H__
 #define __WIN_CONFIG_H__
 

Index: winkeybd.h
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/winkeybd.h,v
retrieving revision 1.1.10.1
retrieving revision 1.1.10.1.4.1
diff -u -d -r1.1.10.1 -r1.1.10.1.4.1
--- a/winkeybd.h	4 Mar 2004 17:48:19 -0000	1.1.10.1
+++ b/winkeybd.h	28 Mar 2004 17:18:11 -0000	1.1.10.1.4.1
@@ -36,7 +36,7 @@
 
 
 /*
- * Include the standard XFree86 ASCII keymap.
+ * Include the standard ASCII keymap.
  *
  * This header declares a static KeySym array called 'map'.
  */

Index: winshaddd.c
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/winshaddd.c,v
retrieving revision 1.1.4.1.6.1
retrieving revision 1.1.4.1.6.1.4.1
diff -u -d -r1.1.4.1.6.1 -r1.1.4.1.6.1.4.1
--- a/winshaddd.c	4 Mar 2004 17:48:19 -0000	1.1.4.1.6.1
+++ b/winshaddd.c	28 Mar 2004 17:18:11 -0000	1.1.4.1.6.1.4.1
@@ -573,7 +573,7 @@
       ErrorF ("winShadowUpdateProcDD - Memory location of the shadow "
 	      "surface has changed, trying to update the root window "
 	      "pixmap header to point to the new address.  If you get "
-	      "this message and Cygwin/XFree86 freezes or crashes "
+	      "this message and Cygwin/X freezes or crashes "
 	      "after this message then send a problem report and your "
 	      "/tmp/XWin.log file to cygwin-xfree at cygwin.com\n");
 

Index: wintrayicon.c
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/wintrayicon.c,v
retrieving revision 1.1.10.1
retrieving revision 1.1.10.1.4.1
diff -u -d -r1.1.10.1 -r1.1.10.1.4.1
--- a/wintrayicon.c	4 Mar 2004 17:48:20 -0000	1.1.10.1
+++ b/wintrayicon.c	28 Mar 2004 17:18:11 -0000	1.1.10.1.4.1
@@ -62,7 +62,7 @@
   /* Set display and screen-specific tooltip text */
   snprintf (nid.szTip,
 	    sizeof (nid.szTip),
-	    "Cygwin/XFree86 Server - %s:%d",
+	    "Cygwin/X Server - %s:%d",
 	    display, 
 	    (int) pScreenInfo->dwScreen);
 

Index: winvideo.c
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/winvideo.c,v
retrieving revision 1.1.10.1
retrieving revision 1.1.10.1.4.1
diff -u -d -r1.1.10.1 -r1.1.10.1.4.1
--- a/winvideo.c	4 Mar 2004 17:48:20 -0000	1.1.10.1
+++ b/winvideo.c	28 Mar 2004 17:18:11 -0000	1.1.10.1.4.1
@@ -144,7 +144,7 @@
 
     adapt->type = XvWindowMask | XvInputMask | XvImageMask;
     adapt->flags = VIDEO_OVERLAID_IMAGES | VIDEO_CLIP_TO_VIEWPORT;
-    adapt->name = "Cygwin/XFree86 Video Overlay";
+    adapt->name = "Cygwin/X Video Overlay";
     adapt->nEncodings = 1;
     adapt->pEncodings = DummyEncoding;
     adapt->nFormats = NUM_FORMATS;

Index: winwindow.h
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/winwindow.h,v
retrieving revision 1.1.4.1.6.1
retrieving revision 1.1.4.1.6.1.4.1
diff -u -d -r1.1.4.1.6.1 -r1.1.4.1.6.1.4.1
--- a/winwindow.h	4 Mar 2004 17:48:20 -0000	1.1.4.1.6.1
+++ b/winwindow.h	28 Mar 2004 17:18:11 -0000	1.1.4.1.6.1.4.1
@@ -41,12 +41,12 @@
 #endif
 
 /* Constant strings */
-#define WINDOW_CLASS		"cygwin/xfree86"
-#define WINDOW_TITLE		"Cygwin/XFree86 - %s:%d"
-#define WINDOW_TITLE_XDMCP	"Cygwin/XFree86 - %s"
+#define WINDOW_CLASS		"cygwin/x"
+#define WINDOW_TITLE		"Cygwin/X - %s:%d"
+#define WINDOW_TITLE_XDMCP	"Cygwin/X - %s"
 #define WIN_SCR_PROP		"cyg_screen_prop rl"
-#define WINDOW_CLASS_X		"cygwin/xfree86 X rl"
-#define WINDOW_TITLE_X		"Cygwin/XFree86 X"
+#define WINDOW_CLASS_X		"cygwin/x X rl"
+#define WINDOW_TITLE_X		"Cygwin/X X"
 #define WIN_WINDOW_PROP		"cyg_window_prop_rl"
 #define WIN_MSG_QUEUE_FNAME	"/dev/windows"
 #define WIN_LOG_FNAME		"/tmp/XWin.log"




More information about the xorg-commit-diffs mailing list
Index: InitOutput.c
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/xwin/InitOutput.c,v
retrieving revision 1.1.4.1.6.1
retrieving revision 1.1.4.1.6.1.4.1
diff -u -d -r1.1.4.1.6.1 -r1.1.4.1.6.1.4.1
--- a/InitOutput.c	4 Mar 2004 17:48:19 -0000	1.1.4.1.6.1
+++ b/InitOutput.c	28 Mar 2004 17:18:11 -0000	1.1.4.1.6.1.4.1
@@ -312,7 +312,7 @@
 
   ErrorF ("-lesspointer\n"
 	  "\tHide the windows mouse pointer when it is over an inactive\n"
-          "\tXFree86 window.  This prevents ghost cursors appearing where\n"
+          "\tX window.  This prevents ghost cursors appearing where\n"
 	  "\tthe Windows cursor is drawn overtop of the X cursor\n");
 
   ErrorF ("-nodecoration\n"
@@ -361,7 +361,7 @@
   ErrorF ("-[no]winkill\n"
           "\tAlt+F4 exits the X Server.\n");
 
-  ErrorF ("-xf86config\n"
+  ErrorF ("-config\n"
           "\tSpecify a configuration file.\n");
 
   ErrorF ("-keyboard\n"
@@ -1201,9 +1201,9 @@
     }
 
   /*
    * Look for the '-xf86config' argument
    */
-  if (IS_OPTION ("-xf86config"))
+  if (IS_OPTION ("-config") || IS_OPTION ("-xf86config"))
     {
       CHECK_ARGS (1);
       g_cmdline.configFile = argv[++i];
@@ -1270,7 +1270,7 @@
   ErrorF ("InitOutput\n");
 #endif
 
-  /* Try to read the XF86Config-style configuration file */
+  /* Try to read the xorg.conf-style configuration file */
   if (!winReadConfigfile ())
     ErrorF ("InitOutput - Error reading config file\n");
 
@@ -1201,9 +1201,9 @@
 
   /*
-   * Look for the '-xf86config' argument
+   * Look for the '-config' argument.  Accept -xf86config as an alias
    */
